@@ -1,7 +1,7 @@
 
 /*
  * Ekiga -- A VoIP and Video-Conferencing application
- * Copyright (C) 2000-2007 Damien Sandras
+ * Copyright (C) 2000-2009 Damien Sandras <dsandras@seconix.com>
 
  * This program is free software; you can  redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -36,13 +36,12 @@
 #ifndef __SERVICES_H__
 #define __SERVICES_H__
 
-/* Ok, the principle is simple : we want to do "foo = new Foo (whatever)"
- * somewhere, and hook it somewhere for the whole program life ; so we give
- * the pointer to a ServiceCore object, which will end it cleanly.
- * Why not use smart pointers? Because it would be nice for debugging purposes
- * to be able to describe what exactly is enabled.
+/* We want to register some named services to a central location : this is
+ * it!
  */
 
+#include "gmref.h"
+
 #include <list>
 #include <string>
 #include <sigc++/sigc++.h>
@@ -55,7 +54,7 @@ namespace Ekiga
  * @{
  */
 
-  struct Service
+  struct Service: public virtual GmRefCounted
   {
     virtual ~Service () {}
 
@@ -73,20 +72,41 @@ namespace Ekiga
 
     ~ServiceCore ();
 
-    bool add (Service &service);
+    bool add (gmref_ptr<Service> service);
 
-    Service *get (const std::string name);
+    gmref_ptr<Service> get (const std::string name);
 
     void dump (std::ostream &stream) const;
 
-   sigc::signal<void, Service &> service_added;
+    sigc::signal1<void, gmref_ptr<Service> > service_added;
 
   private:
 
-    std::list<Service *> services;
+    std::list<gmref_ptr<Service> > services;
 
   };
 
+  class BasicService: public Service
+  {
+  public:
+
+    BasicService (const std::string name_,
+		  const std::string description_):
+      name(name_), description(description_)
+    {}
+
+    const std::string get_name () const
+    { return name; }
+
+    const std::string get_description () const
+    { return description; }
+
+  private:
+
+    std::string name;
+    std::string description;
+  };
+
 /**
  * @}
  */
