@@ -431,6 +431,9 @@ on_extlink_tag_event (GtkTextTag* tag,
   case GDK_SETTING:
   case GDK_OWNER_CHANGE:
   case GDK_GRAB_BROKEN:
+#if GTK_CHECK_VERSION(2,14,0)
+  case GDK_DAMAGE:
+#endif
   default:
     result = FALSE; // nothing
     break; // nothing
@@ -1009,7 +1012,7 @@ GtkWidget*
 chat_area_new (gmref_ptr<Ekiga::Chat> chat)
 {
   return (GtkWidget*)g_object_new (TYPE_CHAT_AREA,
-				   "chat", &*chat,
+				   "chat", chat.get (),
 				   NULL);
 }
 
